@@ -7,11 +7,15 @@ from ..datasets import AttckDatasets
 
 class MobileAttckActor(MobileAttckObject):
 
-    '''A child class of MobileAttckObject
-    
-    Creates objects that are categorized as MITRE Mobile ATT&CK Actors or Groups (e.g. APT1, APT32, etc.)
+    """Mobile MITRE ATT&CK Actor object.
 
-    You can also access external data properties. The following properties are generated using external data:
+    A child class of MobileAttckObject
+
+    Creates objects that are categorized as MITRE Mobile ATT&CK
+    Actors or Groups (e.g. APT1, APT32, etc.)
+
+    You can also access external data properties. The following properties
+    are generated using external data:
 
         1. country
         2. operations
@@ -24,9 +28,9 @@ class MobileAttckActor(MobileAttckObject):
     You can retrieve the entire dataset using the `external_dataset` property.
 
     pyattck also enables you to retrieve or generate logos for the actor or group using the following properties:
-        
+
         - ascii_logo - Generated ASCII logo based on the actor or groups name
-    
+
     Example:
         You can iterate over an `actors` list and access specific properties and relationship properties.
 
@@ -34,11 +38,11 @@ class MobileAttckActor(MobileAttckObject):
                 1. malwares
                 2. tools
                 3. techniques
-        
+
             1. To iterate over an `actors` list, do the following:
 
             .. code-block:: python
-               
+
                from pyattck import Attck
 
                attck = Attck()
@@ -68,22 +72,24 @@ class MobileAttckActor(MobileAttckObject):
                        print(malware.name)
                        print(malware.description)
                        # etc.
-    '''
+    """
 
     __ATTCK_DATASETS = None
 
     def __init__(self, mobile_attck_obj = None, **kwargs):
-        """This class represents a Actor (or group) as defined with the Mobile MITRE ATT&CK framework.
+        """
+        This class represents a Actor (or group) as defined by
+        the Mobile MITRE ATT&CK framework.
 
         Keyword Arguments:
             attck_obj {json} -- A Mobile MITRE ATT&CK Framework json object (default: {None})
 
         Raises:
-            GeneratedDatasetException: Raised an exception when unable to access or process the external generated dataset.
+            GeneratedDatasetException: Raised an exception when unable to access or
+                                       process the external generated dataset.
         """
         super(MobileAttckActor, self).__init__(**kwargs)
         self.__mobile_attck_obj = mobile_attck_obj
-
         self.created_by_ref = self._set_attribute(kwargs, 'created_by_ref')
         self.revoked = self._set_attribute(kwargs, 'revoked')
         self.external_reference = self._set_reference(kwargs)
@@ -91,23 +97,20 @@ class MobileAttckActor(MobileAttckObject):
         self.version = self._set_attribute(kwargs, 'x_mitre_version')
         self.contributor = self._set_list_items(kwargs, 'x_mitre_contributors')
         self.wiki = self._set_wiki(kwargs)
-        
         self.set_relationships(self.__mobile_attck_obj)
-
         logo = Logo(self.name.strip().replace(' ','_').lower())
         self.ascii_logo = logo.get_ascii()
+        self.__retrieve_datasets()
 
-
+    def __retrieve_datasets(self):
         if MobileAttckActor.__ATTCK_DATASETS is None:
             try:
-                data = AttckDatasets().generated_attck_data()
+                data = AttckDatasets().get_data(data_type='generated_data')
                 if 'actors' in data:
                     MobileAttckActor.__ATTCK_DATASETS = data['actors']
             except:
                 raise GeneratedDatasetException('Unable to retrieve generated attack data properties')
-            
         self.external_dataset = self.__get_actors_dataset()
-        
 
     def __get_actors_dataset(self):
         return_list = []
@@ -193,13 +196,15 @@ class MobileAttckActor(MobileAttckObject):
         else:
             return None
 
-
     @property
     def malwares(self):
-        """Returns all malware objects as a list that are documented as being used by an Actor or Group
+        """
+        Returns all malware objects as a list that are documented as
+        being used by an Actor or Group
 
         Returns:
-            [list] -- A list of related malware objects defined within the Mobile MITRE ATT&CK Framework
+            [list] -- A list of related malware objects defined within the
+                      Mobile MITRE ATT&CK Framework
         """
         from .malware import MobileAttckMalware
         return_list = []
@@ -208,18 +213,20 @@ class MobileAttckActor(MobileAttckObject):
             if 'type' in item:
                 if item['type'] == 'malware':
                     item_dict[item['id']] = item
-        
         for item in self._RELATIONSHIPS[self.stix]:
             if item in item_dict:
-                return_list.append(MobileAttckMalware(**item_dict[item]))
+                return_list.append(MobileAttckMalware(mobile_attck_obj=self.__mobile_attck_obj, **item_dict[item]))
         return return_list
 
     @property
     def tools(self):
-        """Returns all tool object as a list that are documented as being used by an Actor or Group
+        """
+        Returns all tool object as a list that are documented as
+        being used by an Actor or Group
 
         Returns:
-            [list] -- A list of related tool objects defined within the Mobile MITRE ATT&CK Framework
+            [list] -- A list of related tool objects defined within the
+                      Mobile MITRE ATT&CK Framework
         """
         from .tools import MobileAttckTools
         return_list = []
@@ -228,18 +235,19 @@ class MobileAttckActor(MobileAttckObject):
             if 'type' in item:
                 if item['type'] == 'tool':
                     item_dict[item['id']] = item
-        
         for item in self._RELATIONSHIPS[self.stix]:
             if item in item_dict:
-                return_list.append(MobileAttckTools(**item_dict[item]))
+                return_list.append(MobileAttckTools(mobile_attck_obj=self.__mobile_attck_obj, **item_dict[item]))
         return return_list
 
     @property
     def techniques(self):
-        """Returns all technique objects as a list that are documented as being used by an Actor or Group
+        """Returns all technique objects as a list that are documented as
+        being used by an Actor or Group
 
         Returns:
-            [list] -- A list of related technique objects defined within the Mobile MITRE ATT&CK Framework
+            [list] -- A list of related technique objects defined within the
+                      Mobile MITRE ATT&CK Framework
         """
         from .technique import MobileAttckTechnique
         return_list = []
@@ -248,8 +256,7 @@ class MobileAttckActor(MobileAttckObject):
             if 'type' in item:
                 if item['type'] == 'attack-pattern':
                     item_dict[item['id']] = item
-        
         for item in self._RELATIONSHIPS[self.stix]:
             if item in item_dict:
-                return_list.append(MobileAttckTechnique(**item_dict[item]))
-        return return_list
\ No newline at end of file
+                return_list.append(MobileAttckTechnique(mobile_attck_obj=self.__mobile_attck_obj, **item_dict[item]))
+        return return_list
