@@ -1,20 +1,24 @@
 
 
 class MobileAttckObject(object):
-    '''Parent class of all other MITRE Mobile ATT&CK based classes
+
+    """Mobile MITRE ATT&CK Parent object.
+
+    Parent class of all other MITRE Mobile ATT&CK based classes
 
     This is a private class and should not be accessed directly
-    
+
     Arguments:
         AttckObject (dict) -- Takes the MITRE Mobile ATT&CK Json object as a kwargs values
-    '''
+    """
 
     _RELATIONSHIPS = None
-    
+
     def __init__(self, **kwargs):
         """
-        Sets standard properties that are found in all child classes as well as provides standard methods used by inherited classes
-        
+        Sets standard properties that are found in all child classes as well as
+        provides standard methods used by inherited classes
+
         Arguments:
             kwargs (dict) -- Takes the MITRE Mobile ATT&CK Json object as a kwargs values
         """
@@ -27,7 +31,6 @@ class MobileAttckObject(object):
         self.modified = self._set_attribute(kwargs, 'modified')
         self.stix = self._set_attribute(kwargs, 'id')
         self.type = self._set_attribute(kwargs, 'type')
-        
 
     def __str__(self):
         return_dict = {}
@@ -37,8 +40,10 @@ class MobileAttckObject(object):
         return str(return_dict)
 
     def set_relationships(self, attck_obj):
-        """Generates relationships within attck_obj based on a defined relationship from MITRE ATT&CK
-        
+        """
+        Generates relationships within attck_obj based on a defined
+        relationship from MITRE ATT&CK
+
         Args:
             attck_obj (dict): MITRE ATT&CK Json object
         """
@@ -52,18 +57,18 @@ class MobileAttckObject(object):
                         if source_id not in relationship_obj:
                             relationship_obj[source_id] = []
                         relationship_obj[source_id].append(target_id)
-
                         if target_id not in relationship_obj:
                             relationship_obj[target_id] = []
                         relationship_obj[target_id].append(source_id)
             MobileAttckObject._RELATIONSHIPS = relationship_obj
 
     def __set_alias(self, obj):
-        """Returns the Mitre ATT&CK Framework aliases
-        
+        """
+        Returns the Mitre ATT&CK Framework aliases
+
         Arguments:
             obj (dict) -- A Mitre ATT&CK Framework json object
-        
+
         Returns:
             (str) -- Returns the Mitre ATT&CK Framework aliases
         """
@@ -75,15 +80,16 @@ class MobileAttckObject(object):
             for item in obj['x_mitre_aliases']:
                 return_list.append(item)
         return return_list
-        
+
     def _set_attribute(self, obj, name):
-        """Parent class method to set attribute based on passed in object
-           and the name of the property
-        
+        """
+        Parent class method to set attribute based on passed
+        in object and the name of the property
+
         Arguments:
             obj (dict) -- Provided json objects are passed to this method
             name (str) -- The json property name to set attribute in child classes
-        
+
         Returns:
             (str) -- Returns either the value of the attribute requested or returns 'null'
         """
@@ -93,17 +99,17 @@ class MobileAttckObject(object):
         except:
             return None
 
-
     def _set_list_items(self, obj, list_name):
         """Private method used by child classes and normalizes list items
-        
+
         Args:
             obj (dict) -- Provided json objects are passed to this method
-            list_name (str) -- The json property name to set list items attribute in child classes
-        
+            list_name (str) -- The json property name to set list items
+                               attribute in child classes
+
         Returns:
             list: returns a list of values from the provided list_name property
-        """        
+        """
         item_value = []
         if list_name in obj:
             for item in obj[list_name]:
@@ -111,11 +117,12 @@ class MobileAttckObject(object):
             return item_value
 
     def _set_id(self, obj):
-        """Returns the MITRE Mobile ATT&CK Framework external ID 
-        
+        """
+        Returns the MITRE Mobile ATT&CK Framework external ID
+
         Arguments:
             obj (dict) -- A MITRE Mobile ATT&CK Framework json object
-        
+
         Returns:
             (str) -- Returns the MITRE Mobile ATT&CK Framework external ID
         """
@@ -123,13 +130,14 @@ class MobileAttckObject(object):
             for p in obj['external_references']:
                 if p.get('source_name') == 'mitre-mobile-attack' or p.get('source_name') == 'mitre-attack':
                     return p.get('external_id')
-        
+
     def _set_wiki(self, obj):
-        """Returns the MITRE Mobile ATT&CK Framework Wiki URL
-        
+        """
+        Returns the MITRE Mobile ATT&CK Framework Wiki URL
+
         Arguments:
             obj (dict) -- A MITRE Mobile ATT&CK Framework json object
-        
+
         Returns:
             (str) -- Returns the MITRE Mobile ATT&CK Framework Wiki URL
         """
@@ -138,19 +146,21 @@ class MobileAttckObject(object):
                 if p.get('source_name') == 'mitre-mobile-attack' or p.get('source_name') == 'mitre-attack':
                     return p.get('url')
 
-
     def _set_reference(self, obj):
-        """Returns a list of external references from the provided MITRE Mobile ATT&CK Framework json object
-        
+        """
+        Returns a list of external references from the provided
+        MITRE Mobile ATT&CK Framework json object
+
         Arguments:
             obj (dict) -- A MITRE Mobile ATT&CK Framework json object
-        
+
         Returns:
             (dict) -- Returns a dict containing the following key/value pairs
                 external_id (str) -- The MITRE Mobile ATT&CK Framework external ID
                 url (str)         -- The MITRE Mobile ATT&CK Framework URL
                 source_name (str) -- The MITRE Mobile ATT&CK Framework source name
-                description (str) -- The MITRE Mobile ATT&CK Framework description or None if it does not exist
+                description (str) -- The MITRE Mobile ATT&CK Framework description
+                                     or None if it does not exist
         """
         return_list = []
         if obj.get('external_references'):
