@@ -4,113 +4,118 @@ from ..utils.exceptions import GeneratedDatasetException
 
 
 class MobileAttckTools(MobileAttckObject):
-    '''
-        A child class of MobileAttckObject
-    
-        Creates objects which have been categorized as tools or software which have been categorized as software used in attacks
-        
-        You can also access external data properties. The following properties are generated using external data:
 
-            1. additional_names
-            2. attribution_links
-            3. additional_comments
-            4. family
+    """Mobile MITRE ATT&CK Tool object.
 
-        You can retrieve the entire dataset using the `external_dataset` property.
+    A child class of MobileAttckObject
 
-        You can also access external data properties from the C2 Matrix project. The following properties are generated using C2 Matrix external data:
+    Creates objects which have been categorized as tools or software
+    which have been categorized as software used in attacks
 
-            - HTTP
-            - Implementation
-            - Custom Profile
-            - DomainFront
-            - Multi-User
-            - SMB
-            - Kill Date
-            - macOS
-            - GitHub
-            - Key Exchange
-            - Chaining
-            - Price
-            - TCP
-            - Proxy Aware
-            - HTTP3
-            - HTTP2
-            - Date
-            - Evaluator
-            - Working Hours
-            - Slack
-            - FTP
-            - Version Reviewed
-            - Logging
-            - Name
-            - License
-            - Windows
-            - Stego
-            - Notes
-            - Server
-            - Actively Maint.
-            - Dashboard
-            - DNS
-            - Popular Site
-            - ICMP
-            - IMAP
-            - DoH
-            - Jitter
-            - How-To
-            - ATT&CK Mapping
-            - Kali
-            - Twitter
-            - MAPI
-            - Site
-            - Agent
-            - API
-            - UI
-            - Linux
+    You can also access external data properties. The following
+    properties are generated using external data:
 
-        You can retrieve the entire dataset using the `c2_data` property.
+        1. additional_names
+        2. attribution_links
+        3. additional_comments
+        4. family
 
+    You can retrieve the entire dataset using the `external_dataset` property.
 
-        Example:
-            You can iterate over an `tools` list and access specific properties and relationship properties.
+    You can also access external data properties from the C2 Matrix project.
+    The following properties are generated using C2 Matrix external data:
 
-            The following relationship properties are accessible:
-                    1. techniques
-                    2. actors
-            
-                1. To iterate over an `tools` list, do the following:
+        - HTTP
+        - Implementation
+        - Custom Profile
+        - DomainFront
+        - Multi-User
+        - SMB
+        - Kill Date
+        - macOS
+        - GitHub
+        - Key Exchange
+        - Chaining
+        - Price
+        - TCP
+        - Proxy Aware
+        - HTTP3
+        - HTTP2
+        - Date
+        - Evaluator
+        - Working Hours
+        - Slack
+        - FTP
+        - Version Reviewed
+        - Logging
+        - Name
+        - License
+        - Windows
+        - Stego
+        - Notes
+        - Server
+        - Actively Maint.
+        - Dashboard
+        - DNS
+        - Popular Site
+        - ICMP
+        - IMAP
+        - DoH
+        - Jitter
+        - How-To
+        - ATT&CK Mapping
+        - Kali
+        - Twitter
+        - MAPI
+        - Site
+        - Agent
+        - API
+        - UI
+        - Linux
 
-                .. code-block:: python
-                
-                from pyattck import Attck
+    You can retrieve the entire dataset using the `c2_data` property.
 
-                attck = Attck()
+    Example:
+        You can iterate over an `tools` list and access specific properties
+        and relationship properties.
 
-                for tool in attck.mobile.tools:
-                    print(tool.id)
-                    print(tool.name)
-                    print(tool.description)
+        The following relationship properties are accessible:
+                1. techniques
+                2. actors
+
+            1. To iterate over an `tools` list, do the following:
+
+            .. code-block:: python
+
+            from pyattck import Attck
+
+            attck = Attck()
+
+            for tool in attck.mobile.tools:
+                print(tool.id)
+                print(tool.name)
+                print(tool.description)
+                # etc.
+
+            2. To access relationship properties, do the following:
+
+            .. code-block:: python
+
+            from pyattck import Attck
+
+            attck = Attck()
+
+            for tool in attck.mobile.tools:
+                print(tool.id)
+                print(tool.name)
+                print(tool.description)
+                # etc.
+
+                for technique in tool.techniques:
+                    print(technique.name)
+                    print(technique.description)
                     # etc.
-
-                2. To access relationship properties, do the following:
-
-                .. code-block:: python
-
-                from pyattck import Attck
-
-                attck = Attck()
-
-                for tool in attck.mobile.tools:
-                    print(tool.id)
-                    print(tool.name)
-                    print(tool.description)
-                    # etc.
-
-                    for technique in tool.techniques:
-                        print(technique.name)
-                        print(technique.description)
-                        # etc.
-    '''
+    """
 
     __ATTCK_C2_DATASETS = None
     __ATTCK_TOOLS_DATASETS = None
@@ -118,15 +123,17 @@ class MobileAttckTools(MobileAttckObject):
     def __init__(self, mobile_attck_obj = None, **kwargs):
         """
         Creates an MobileAttckTools object.  
-        The MobileAttckTools object is based on software which have been categorized as software used in attacks
-        
+        The MobileAttckTools object is based on software which have been
+        categorized as software used in attacks
+
         Arguments:
-            mobile_attck_obj (json) -- Takes the raw MITRE Mobile ATT&CK Json object
-            AttckObject (dict) -- Takes the MITRE Mobile ATT&CK Json object as a kwargs values
+            mobile_attck_obj (json) -- Takes the raw MITRE Mobile
+                                       ATT&CK Json object
+            AttckObject (dict) -- Takes the MITRE Mobile ATT&CK Json object
+                                  as a kwargs values
         """
         super(MobileAttckTools, self).__init__(**kwargs)
         self.__mobile_attck_obj = mobile_attck_obj
-      
         self.external_reference = self._set_reference(kwargs)
         self.platforms = self._set_list_items(kwargs, 'x_mitre_platforms')
         self.version = self._set_attribute(kwargs, 'x_mitre_version')
@@ -136,12 +143,15 @@ class MobileAttckTools(MobileAttckObject):
         self.old_attack_id = self._set_attribute(kwargs, 'x_mitre_old_attack_id')
         self.stix = self._set_attribute(kwargs, 'id')
         self.wiki = self._set_wiki(kwargs)
-        
         self.set_relationships(self.__mobile_attck_obj)
+        self.__retrieve_datasets()
+        self.c2_data = self.__get_c2_dataset()
+        self.external_dataset =  self.__get_tools_dataset()
 
+    def __retrieve_datasets(self):
         if MobileAttckTools.__ATTCK_C2_DATASETS is None or MobileAttckTools.__ATTCK_TOOLS_DATASETS is None:
             try:
-                data = AttckDatasets().generated_attck_data()
+                data = AttckDatasets().get_data(data_type='generated_data')
             except:
                 raise GeneratedDatasetException('Unable to retrieve generated attack data properties')
             if MobileAttckTools.__ATTCK_C2_DATASETS is None:
@@ -151,11 +161,6 @@ class MobileAttckTools(MobileAttckObject):
                 if 'tools' in data:
                     MobileAttckTools.__ATTCK_TOOLS_DATASETS = data['tools']
 
-        self.c2_data = self.__get_c2_dataset()
-        self.external_dataset =  self.__get_tools_dataset()
-
-
-
     def __get_tools_dataset(self):
         return_list = []
         self.additional_names = []
@@ -224,10 +229,13 @@ class MobileAttckTools(MobileAttckObject):
 
     @property
     def techniques(self):
-        """Accessing techniques which have been seen using a specific tool as part of the MITRE Mobile ATT&CK Framework
+        """
+        Accessing techniques which have been seen using a specific tool
+        as part of the MITRE Mobile ATT&CK Framework
 
         Returns:
-            list: Returns all technique objects as a list that are associated with a tool
+            list: Returns all technique objects as a list that are associated
+                  with a tool
         """
         from .technique import MobileAttckTechnique
         return_list = []
@@ -236,15 +244,16 @@ class MobileAttckTools(MobileAttckObject):
             if 'type' in item:
                 if item['type'] == 'attack-pattern':
                     item_dict[item['id']] = item
-        
         for item in self._RELATIONSHIPS[self.stix]:
             if item in item_dict:
-                return_list.append(MobileAttckTechnique(**item_dict[item]))
+                return_list.append(MobileAttckTechnique(mobile_attck_obj=self.__mobile_attck_obj, **item_dict[item]))
         return return_list
 
     @property
     def actors(self):
-        """Accessing actors which have been identified as using a specific tool as part of the MITRE Mobile ATT&CK Framework
+        """
+        Accessing actors which have been identified as using a specific tool
+        as part of the MITRE Mobile ATT&CK Framework
 
         Returns:
             list: Returns all actor objects as a list that are associated with a tool
@@ -256,8 +265,7 @@ class MobileAttckTools(MobileAttckObject):
             if 'type' in item:
                 if item['type'] == 'intrusion-set':
                     item_dict[item['id']] = item
-        
         for item in self._RELATIONSHIPS[self.stix]:
             if item in item_dict:
-                return_list.append(MobileAttckActor(**item_dict[item]))
-        return return_list
\ No newline at end of file
+                return_list.append(MobileAttckActor(mobile_attck_obj=self.__mobile_attck_obj, **item_dict[item]))
+        return return_list
