@@ -1,20 +1,22 @@
-
-
 class PreAttckObject(object):
-    '''
-        Parent class of all other MITRE PRE-ATT&CK based classes
 
-        This is a private class and should not be accessed directly
-    '''
+    """MITRE PRE-ATT&CK parent object.
+
+    Parent class of all other MITRE PRE-ATT&CK based classes
+
+    This is a private class and should not be accessed directly
+    """
 
     _RELATIONSHIPS = None
-    
+
     def __init__(self, **kwargs):
         """
-        Sets standard properties that are found in all child classes as well as provides standard methods used by inherited classes
-        
+        Sets standard properties that are found in all child classes
+        as well as provides standard methods used by inherited classes
+
         Arguments:
-            kwargs (dict) -- Takes the MITRE PRE-ATT&CK Json object as a kwargs values
+            kwargs (dict) -- Takes the MITRE PRE-ATT&CK Json object as
+                             a kwargs values
         """
         self.id = self._set_id(kwargs)
         self.name = self._set_attribute(kwargs, 'name')
@@ -24,7 +26,6 @@ class PreAttckObject(object):
         self.created = self._set_attribute(kwargs, 'created')
         self.modified = self._set_attribute(kwargs, 'modified')
         self.type = self._set_attribute(kwargs, 'type')
-        
 
     def __str__(self):
         return_dict = {}
@@ -34,8 +35,10 @@ class PreAttckObject(object):
         return str(return_dict)
 
     def set_relationships(self, attck_obj):
-        """Generates relationships within attck_obj based on a defined relationship from MITRE ATT&CK
-        
+        """
+        Generates relationships within attck_obj based on
+        a defined relationship from MITRE ATT&CK
+
         Args:
             attck_obj (dict): MITRE ATT&CK Json object
         """
@@ -49,18 +52,18 @@ class PreAttckObject(object):
                         if source_id not in relationship_obj:
                             relationship_obj[source_id] = []
                         relationship_obj[source_id].append(target_id)
-
                         if target_id not in relationship_obj:
                             relationship_obj[target_id] = []
                         relationship_obj[target_id].append(source_id)
             PreAttckObject._RELATIONSHIPS = relationship_obj
 
     def __set_alias(self, obj):
-        """Returns the Mitre ATT&CK Framework aliases
-        
+        """
+        Returns the Mitre ATT&CK Framework aliases
+
         Arguments:
             obj (dict) -- A Mitre ATT&CK Framework json object
-        
+
         Returns:
             (str) -- Returns the Mitre ATT&CK Framework aliases
         """
@@ -73,17 +76,18 @@ class PreAttckObject(object):
                 return_list.append(item)
         return return_list
 
-
     def _set_attribute(self, obj, name):
-        """Parent class method to set attribute based on passed in object
-           and the name of the property
-        
+        """
+        Parent class method to set attribute based on passed in object
+        and the name of the property
+
         Arguments:
             obj (dict) -- Provided json objects are passed to this method
             name (str) -- The json property name to set attribute in child classes
-        
+
         Returns:
-            (str) -- Returns either the value of the attribute requested or returns 'null'
+            (str) -- Returns either the value of the attribute requested
+                     or returns 'null'
         """
         try:
             value = obj.get(name)
@@ -91,17 +95,18 @@ class PreAttckObject(object):
         except:
             return None
 
-
     def _set_list_items(self, obj, list_name):
-        """Private method used by child classes and normalizes list items
-        
+        """
+        Private method used by child classes and normalizes list items
+
         Args:
             obj (dict) -- Provided json objects are passed to this method
-            list_name (str) -- The json property name to set list items attribute in child classes
-        
+            list_name (str) -- The json property name to set list items
+                               attribute in child classes
+
         Returns:
             list: returns a list of values from the provided list_name property
-        """        
+        """
         item_value = []
         if list_name in obj:
             for item in obj[list_name]:
@@ -109,11 +114,12 @@ class PreAttckObject(object):
             return item_value
 
     def _set_id(self, obj):
-        """Returns the MITRE PRE-ATT&CK Framework external ID 
-        
+        """
+        Returns the MITRE PRE-ATT&CK Framework external ID
+
         Arguments:
             obj (dict) -- A MITRE PRE-ATT&CK Framework json object
-        
+
         Returns:
             (str) -- Returns the MITRE PRE-ATT&CK Framework external ID
         """
@@ -122,13 +128,13 @@ class PreAttckObject(object):
                 if p.get('source_name') == 'mitre-pre-attack' or p.get('source_name') == 'mitre-attack':
                     return p.get('external_id')
 
-
     def _set_wiki(self, obj):
-        """Returns the MITRE ATT&CK Framework Wiki URL
-        
+        """
+        Returns the MITRE ATT&CK Framework Wiki URL
+
         Arguments:
             obj (dict) -- A MITRE PRE-ATT&CK Framework json object
-        
+
         Returns:
             (str) -- Returns the MITRE PRE-ATT&CK Framework Wiki URL
         """
@@ -137,19 +143,21 @@ class PreAttckObject(object):
                 if p.get('source_name') == 'mitre-pre-attack' or p.get('source_name') == 'mitre-attack':
                     return p.get('url')
 
-
     def _set_reference(self, obj):
-        """Returns a list of external references from the provided MITRE PRE-ATT&CK Framework json object
-        
+        """
+        Returns a list of external references from the provided
+        MITRE PRE-ATT&CK Framework json object
+
         Arguments:
             obj (dict) -- A MITRE PRE-ATT&CK Framework json object
-        
+
         Returns:
             (dict) -- Returns a dict containing the following key/value pairs
                 external_id (str) -- The MITRE PRE-ATT&CK Framework external ID
                 url (str)         -- The MITRE PRE-ATT&CK Framework URL
                 source_name (str) -- The MITRE PRE-ATT&CK Framework source name
-                description (str) -- The MITRE PRE-ATT&CK Framework description or None if it does not exist
+                description (str) -- The MITRE PRE-ATT&CK Framework description
+                                     or None if it does not exist
         """
         return_list = []
         if obj.get('external_references'):
